pub fn closure_future<Output, F: FnOnce() -> Output>(
f: F,
) -> (ClosureFuture<Output>, ClosureFutureWorker<Output, F>)Expand description
Wraps a closure to be run as a Future
pub fn closure_future<Output, F: FnOnce() -> Output>(
f: F,
) -> (ClosureFuture<Output>, ClosureFutureWorker<Output, F>)Wraps a closure to be run as a Future